@@ -134,6 +134,7 @@ void on_dialog_response(GtkWidget * prefdialog, gint responseId,
         gpointer user_data)
 {
     gboolean close = TRUE;
+    Iphb_cb_data *iphb_data = (Iphb_cb_data *)user_data;
 
     if (responseId == GTK_RESPONSE_CANCEL ||
         responseId == GTK_RESPONSE_DELETE_EVENT) 
@@ -239,7 +240,11 @@ void on_dialog_response(GtkWidget * prefdialog, gint responseId,
         DMSG("--========== Alarm setup (%d) =========--\n", modified);
         if (modified) {
             gconf_client_clear_cache(gconf);
-            setup_alarm_event_now(TRUE);
+	    close_iphb_handle((Iphb_cb_data)(*iphb_data));
+	    remove_iphb_callback(iphb_data->source_id);
+	    iphb_data->source_id = 0;
+            setup_alarm_event(TRUE, iphb_data);
+	    iphb_data->source_id = setup_iphb_callback(iphb_data);
         }
         
         ui_destroy();
